@@ -33,6 +33,34 @@ bl2b <- as.binary(bl2b, littleEndian=FALSE)
 bs2u <- binary(byte(), signed=TRUE)
 bs2u <- as.binary(bs2u, signed=FALSE)
 
+size1BEsigned <- as.binary(2, signed=TRUE, size=1)
+size2BEsigned <- as.binary(2, signed=TRUE, size=2)
+size3BEsigned <- as.binary(2, signed=TRUE, size=3)
+size4BEsigned <- as.binary(2, signed=TRUE, size=4)
+n1BE <- as.binary(1, n=1)
+n2BE <- as.binary(1, n=2)
+n3BE <- as.binary(1, n=3)
+n4BE <- as.binary(1, n=4)
+n5BE <- as.binary(1, n=5)
+n6BE <- as.binary(1, n=6)
+n7BE <- as.binary(1, n=7)
+n8BE <- as.binary(1, n=8)
+
+test_that("Return size as.binary", {
+    expect_that(length(size1BEsigned), equals(byte()))
+    expect_that(length(size2BEsigned), equals(2*byte()))
+    expect_that(length(size3BEsigned), equals(3*byte()))
+    expect_that(length(size4BEsigned), equals(4*byte()))    
+    expect_that(length(n1BE), equals(1))
+    expect_that(length(n2BE), equals(2))
+    expect_that(length(n3BE), equals(3))
+    expect_that(length(n4BE), equals(4))
+    expect_that(length(n5BE), equals(5))
+    expect_that(length(n6BE), equals(6))
+    expect_that(length(n7BE), equals(7))
+    expect_that(length(n8BE), equals(8))
+})
+
 test_that("Lost Attributes", {
     expect_that(class(b), equals(c("binary","logical")))
     expect_that(attr(b, "signed"), equals(FALSE))
